"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (_ref) {
  var t = _ref.types;

  return {
    pre: function pre() {
      this.cache = {};
    },


    visitor: {
      ArrayExpression: function ArrayExpression(path, state) {
        var minimumStringLength = state.opts.minimumStringLength;
        var elements = path.get('elements');

        for (var i = 0; i < elements.length; i++) {
          var elementPath = elements[i];

          if (!elementPath.isStringLiteral()) {
            continue;
          }

          var value = elementPath.node.value;

          // minimumStringLength option to run the transform
          if (value.length < (minimumStringLength || 7)) {
            continue;
          }

          // use a hash?
          if (!this.cache[value]) {
            this.cache[value] = { indexes: 1, firstPath: elementPath };
          } else {
            var cachedValue = this.cache[value];
            cachedValue.indexes++;

            var uid = void 0;
            // after the first duplicate value,
            // create the new variable declaration
            if (cachedValue.indexes === 2) {

              uid = path.scope.generateUidIdentifier("a"); // can use something else
              if (!cachedValue.ref) {
                cachedValue.ref = uid;
              }
              cachedValue.firstPath.replaceWith(uid);

              var declar = t.variableDeclaration("var", [t.variableDeclarator(uid, t.stringLiteral(value))]);
              var childOfProgramPath = elementPath.findParent(function (path) {
                return path.parentPath.isProgram();
              });
              childOfProgramPath.insertBefore(declar);
            } else {
              uid = cachedValue.ref;
            }

            // change the string reference with the
            // newly created variable reference
            elementPath.replaceWith(uid);
          }
        }
      } // ArrayExpression

    }
  };
};